@@ -6,13 +6,13 @@
 
 #include "mboximportkernel.h"
 
-#include <AkonadiCore/session.h>
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Session>
+#include <KIdentityManagement/IdentityManager>
 #include <KSharedConfig>
 #include <MailCommon/FolderCollectionMonitor>
-#include <changerecorder.h>
-#include <entitymimetypefiltermodel.h>
-#include <entitytreemodel.h>
 
 MBoxImporterKernel::MBoxImporterKernel(QObject *parent)
     : QObject(parent)
