@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #include "mboximportwidget.h"
 #include "ui_mboximportwidget.h"
 
-MBoxImportWidget::MBoxImportWidget(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::MBoxImportWidget)
+MBoxImportWidget::MBoxImportWidget(QWidget *parent)
+    : QWidget(parent)
+    , ui(new Ui::MBoxImportWidget)
 {
     ui->setupUi(this);
     connect(ui->importMails, &QAbstractButton::clicked, this, &MBoxImportWidget::importMailsClicked);
@@ -40,4 +40,3 @@ void MBoxImportWidget::setImportButtonEnabled(bool enabled)
 {
     ui->importMails->setEnabled(enabled);
 }
-
